import type { ContentRouting } from '@libp2p/interface-content-routing';
import type { AbortOptions } from '@libp2p/interfaces';
import type { Startable } from '@libp2p/interfaces/startable';
import type { CID } from 'multiformats/cid';
import type { Components } from '@libp2p/components';
export interface CompoundContentRoutingInit {
    routers: ContentRouting[];
}
export declare class CompoundContentRouting implements ContentRouting, Startable {
    private readonly routers;
    private started;
    private readonly components;
    constructor(components: Components, init: CompoundContentRoutingInit);
    isStarted(): boolean;
    start(): Promise<void>;
    stop(): Promise<void>;
    /**
     * Iterates over all content routers in parallel to find providers of the given key
     */
    findProviders(key: CID, options?: AbortOptions): AsyncGenerator<import("@libp2p/interface-peer-info").PeerInfo, void, unknown>;
    /**
     * Iterates over all content routers in parallel to notify it is
     * a provider of the given key
     */
    provide(key: CID, options?: AbortOptions): Promise<void>;
    /**
     * Store the given key/value pair in the available content routings
     */
    put(key: Uint8Array, value: Uint8Array, options?: AbortOptions): Promise<void>;
    /**
     * Get the value to the given key.
     * Times out after 1 minute by default.
     */
    get(key: Uint8Array, options?: AbortOptions): Promise<Uint8Array>;
    /**
     * Get the `n` values to the given key without sorting
     */
    getMany(key: Uint8Array, nVals: number, options: AbortOptions): AsyncGenerator<{
        from: import("@libp2p/interface-peer-id").PeerId;
        val: Uint8Array;
    }, void, unknown>;
}
//# sourceMappingURL=index.d.ts.map